unbind — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# unbind

Purpose

  Convert the current checkout into a regular branch.

Usage

  brz unbind

Options
  `-d ARG, --directory=ARG`

    Branch to operate on, instead of working directory.

  `-h, --help`

    Show help message.

  `-q, --quiet`

    Only display errors and warnings.

  `--usage`

    Show usage message and options.

  `-v, --verbose`

    Display more information.

Description

  After unbinding, the local branch is considered independent and subsequent commits will be local only.

See also

  bind, checkouts